@@ -4,6 +4,7 @@ import (
 	"context"
 	"time"
 
+	"github.com/openshift/elasticsearch-operator/internal/k8shandler/kibana"
 	"github.com/openshift/elasticsearch-operator/internal/metrics"
 
 	"github.com/ViaQ/logerr/log"
@@ -44,6 +45,9 @@ func (r *ElasticsearchReconciler) Reconcile(request ctrl.Request) (ctrl.Result,
 			log.Info("Flushing nodes", "objectKey", request.NamespacedName)
 			k8shandler.FlushNodes(request.NamespacedName.Name, request.NamespacedName.Namespace)
 			k8shandler.RemoveDashboardConfigMap(r.Client)
+			if err := kibana.DeleteKibanaConsoleLink(context.TODO(), r.Client); err != nil {
+				log.Error(err, "failed to delete consolelink")
+			}
 			return ctrl.Result{}, nil
 		}
 
